@@ -1,4 +1,9 @@
-from importlib_metadata import PackageNotFoundError, version
+import sys
+
+if sys.version_info < (3, 8):  # pragma: <3.8 cover
+    from importlib_metadata import PackageNotFoundError, version
+else:  # pragma: >=3.8 cover
+    from importlib.metadata import PackageNotFoundError, version
 
 from .menu import Menu, MenuItem
 
